==> apache-superset-2.1.0-source.tar.gz: apache-superset-2.1.0rc3/superset-frontend/src/components/Table/cell-renderers/NumericCell/NumericCell.stories.tsx <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import React from 'react';
import { ComponentStory, ComponentMeta } from '@storybook/react';
import { CurrencyCode, LocaleCode, NumericCell, Style } from './index';

export default {
  title: 'Design System/Components/Table/Cell Renderers/NumericCell',
  component: NumericCell,
} as ComponentMeta<typeof NumericCell>;

export const Basic: ComponentStory<typeof NumericCell> = args => (
  <NumericCell {...args} />
);

Basic.args = {
  value: 5678943,
};

export const FrenchLocale: ComponentStory<typeof NumericCell> = args => (
  <NumericCell {...args} />
);

FrenchLocale.args = {
  value: 5678943,
  locale: LocaleCode.fr,
  options: {
    style: Style.CURRENCY,
    currency: CurrencyCode.EUR,
  },
};

==> apache-superset-4.0.2-source.tar.gz: apache-superset-4.0.2rc2/superset-frontend/src/components/Table/cell-renderers/NumericCell/NumericCell.stories.tsx <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import React from 'react';
import { ComponentStory, ComponentMeta } from '@storybook/react';
import { CurrencyCode, NumericCell, LocaleCode, Style } from './index';

export default {
  title: 'Design System/Components/Table/Cell Renderers/NumericCell',
  component: NumericCell,
} as ComponentMeta<typeof NumericCell>;

export const Basic: ComponentStory<typeof NumericCell> = args => (
  <NumericCell {...args} />
);

Basic.args = {
  value: 5678943,
};

export const FrenchLocale: ComponentStory<typeof NumericCell> = args => (
  <NumericCell {...args} />
);

FrenchLocale.args = {
  value: 5678943,
  locale: LocaleCode.fr,
  options: {
    style: Style.Currency,
    currency: CurrencyCode.EUR,
  },
};
